@@ -73,7 +73,7 @@ def init(log_level: str):
 
     Steps:
     1. Sets up logging based on --log-level
-    2. Creates/updates cursor rules in .cursor/agent.mdc
+    2. Creates/updates cursor rules in .cursor/ai-kit.mdc
     
     Options:
     --log-level: Set logging level (DEBUG, INFO, WARNING, ERROR)
@@ -264,24 +264,6 @@ def agent():
     """Agent utilities for managing agents."""
     pass
 
-@agent.command(name="browse")
-@click.argument("instruction")
-@click.option("--headless", "-h", is_flag=True, help="Run the browser in headless mode", default=False)
-@registry_instance.add(
-    name="agent browse",
-    description="Run a browser automation task with the given instruction.",
-    usage="ai-kit agent browse [instruction]",
-)
-def browse(instruction: str, headless: bool):
-    """Run browser automation with natural language instructions."""
-    from ai_kit.cli.commands.agent.browse import browse_command
-
-    try:
-        asyncio.run(browse_command(instruction, headless))
-    except Exception as e:
-        shared_error_console.print(f"[red]Error: {str(e)}[/red]")
-        raise click.Abort()
-
 # ! disabling this until fixed
 # @main.command()
 @click.argument("repo")
@@ -291,11 +273,11 @@ def browse(instruction: str, headless: bool):
     help="Directory to save multiple output files (overrides --output-file)",
     default=".",
 )
-@registry_instance.add(
-    name="gitingest",
-    description="Analyze a Git repository and create a prompt-friendly text digest.",
-    usage="ai-kit gitingest <repo> [-o output_file] [-d output_dir]",
-)
+# @registry_instance.add(
+#     name="gitingest",
+#     description="Analyze a Git repository and create a prompt-friendly text digest.",
+#     usage="ai-kit gitingest <repo> [-o output_file] [-d output_dir]",
+# )
 def gitingest(repo: str, output_dir: str):
     """Analyze a Git repository and create a prompt-friendly text digest.
     
