@@ -120,12 +120,8 @@ class DynamicFileLoader:
 
     @staticmethod
     def _load_pdf(file_path: str) -> str:
-        text = []
-        with open(file_path, "rb") as f:
-            reader = PdfReader(f)
-            for page in reader.pages:
-                text.append(page.extract_text())
-        return "\n".join(text)
+        reader = PdfReader(file_path)
+        return "\n".join([page.extract_text() for page in reader.pages])
 
     @staticmethod
     def _load_text(file_path: str) -> str:
